@@ -1,5 +1,5 @@
 package Password::OWASP::AbstractBaseX;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 use Moose::Role;
 use namespace::autoclean;
 
@@ -15,6 +15,12 @@ requires qw(
     check_password
 );
 
+has cost => (
+    is      => 'ro',
+    isa     => 'Int',
+    default => 12,
+);
+
 has hashing => (
     is      => 'ro',
     isa     => enum([qw(sha1 sha256 sha512)]),
@@ -66,7 +72,7 @@ Password::OWASP::AbstractBaseX - Abstract base class to implement OWASP password
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
