@@ -1,5 +1,5 @@
 package Password::OWASP::Scrypt;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 use Moose;
 
 # ABSTRACT: An Scrypt implemenation of Password::OWASP
@@ -14,7 +14,7 @@ sub crypt_password {
     my ($self, $pass) = @_;
 
     my $ppr = Authen::Passphrase::Scrypt->new(
-        cost        => 12,
+        cost        => $self->cost,
         salt_random => 1,
         passphrase  => $self->hash_password($pass),
     );
@@ -64,7 +64,7 @@ Password::OWASP::Scrypt - An Scrypt implemenation of Password::OWASP
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
